/* REXX */

/*
Monitoring MQ events from the mainframe

REXX code for application
*/

arg mq_server mq_queue .

/* Initialize the interface */

RXMQVTRACE = ''
return_code= RXMQV('INIT')
say 'init rc='word(return_code,1)

/* Connect to Queue Manager */

RXMQVTRACE = ''
return_code = RXMQV('CONN',mq_server)
say 'conn rc='word(return_code,1)

/* Open localq */

RXMQVTRACE = ''
return_code = RXMQV('OPEN',mq_queue,mqoo_input_shared,'h2','ood.')
say 'open rc='word(return_code,1)

/* Get messages from queue (loop) */

do i=1
  message.0 = 250
  message.1 = ""
  igmo.opt  = mqgmo_wait+mqgmo_fail_if_quiescing+mqgmo_convert
  igmo.wait = mqwi_unlimited
  RXMQVTRACE = ''
  return_code = RXMQV('GET',h2,'message.','igmd.','ogmd.','igmo.','ogmo.')
  say 'get  rc='word(return_code,1)
  if (word(return_code,1) <> 0) then leave

  server = substr(message.1,57,8)

  localq = substr(message.1,125,44)

  alert_char = substr(message.1,31,2)

  alert_hex  = c2x(alert_char)

  select
   when (alert_hex = '08B0') then do
                                  alert  = 'Queue depth HIGH'
                                  msg_id = 'SLMQ0051'
                             end
   when (alert_hex = '0805') then do
                                  alert = 'Queue FULL'
                                  msg_id = 'SLMQ0053'
                             end
   when (alert_hex = '08B1') then iterate
   when (alert_hex = '08AE') then iterate
   otherwise do
             alert = 'Unknown('||alert_hex||')'
             msg_id = 'SLMQ0059'
             end
  end

  wto_message = msg_id||' MQmgr='||server||', Alert='||alert||,
                ', Time='ogmd.pt||,
                ', Date='ogmd.pd||,
                ', Queue name='||localq

  address linkmvs ldmwto1 'wto_message'

  say wto_message

  /* Use for diagnostics
  say 'ogmd.pd    ' ogmd.pd
  say 'ogmd.pt    ' ogmd.pt
  say 'ogmd.form  ' ogmd.form
  say 'ogmd.pan   ' ogmd.pan
  say 'ogmd.rtoqm ' ogmd.rtoqm

  do loop_zlist = 1 to words(ogmo.zlist)
     ts = word(ogmo.zlist,loop_zlist)
     ogmo.ts = translate(ogmo.ts,'','00'x)
     ogmo.ts = Strip(ogmo.ts,'B')
     say 'ogmo.'ts ogmo.ts
  end
  */

end

/* Close localq */

RXMQVTRACE = ''
return_code = RXMQV('CLOSE',h2,mqco_none)
say 'close rc='word(return_code,1)

/* Disconnect queue manager  */

RXMQVTRACE = ''
return_code = RXMQV('DISC',queue_manager)
say 'disc rc='word(return_code,1)

/* Remove the interface functions from the REXX workspace ... */

RXMQVTRACE = ''
return_code = RXMQV('TERM',)
say 'term rc='word(return_code,1)

return





******************************************************
Monitoring MQ events from the mainframe

MQ definitions on SL028457

DELETE QLOCAL('SYSTEM.ADMIN.QMGR.EVENT')

DEFINE QALIAS('SYSTEM.ADMIN.QMGR.EVENT') REPLACE +
       DESCR('Alias name for system queue manager events') +
       TARGQ('SL028457.EVENT.REMOTEQ')

DELETE QLOCAL('SYSTEM.ADMIN.PERFM.EVENT')

DEFINE QALIAS('SYSTEM.ADMIN.PERFM.EVENT') REPLACE +
       DESCR('Alias name for system performance events') +
       TARGQ('SL028457.EVENT.REMOTEQ')

ALTER QMGR PERFMEV(ENABLED)
ALTER QMGR STRSTPEV(ENABLED)

DEFINE CHANNEL(SL028457.TO.INM1) chltypE(SDR) TRPTYPE(TCP) +
        REPLACE CONNAME(10.1.1.85) XMITQ(SL028457.TO.INM1.XMITQ) +
        DESCR('Channel to remote qmgr')

DEFINE QLOCAL(SL028457.TO.INM1.XMITQ) USAGE(XMITQ) +
        REPLACE PROCESS(SL028457.TO.INM1.SEND.PROCESS) +
        DEFPSIST(NO) +
        TRIGGER TRIGTYPE(EVERY) TRIGDPTH(1) +
         INITQ(SYSTEM.CHANNEL.INITQ) +
        GET(ENABLED) PUT(ENABLED) +
        DESCR('Transmission queue')

DEFINE QREMOTE(SL028457.EVENT.REMOTEQ) +
        RNAME(SL028457.EVENT.LOCALQ) +
        REPLACE RQMNAME(INM1) XMITQ(SL028457.TO.INM1.XMITQ) +
        DEFPSIST(NO) +
        PUT(ENABLED) +
        DESCR('Points to local queue on remote qmgr')

DEFINE PROCESS(SL028457.TO.INM1.SEND.PROCESS) +
        REPLACE APPLTYPE(OS2) USERDATA(SL028457.TO.INM1)
MQ definitions on INM1
DEFINE CHANNEL('SL028457.TO.INM1') +
       CHLTYPE(RCVR) +
       REPLACE +
       DESCR('Channel for receiving messages from SL028457')

DEFINE QLOCAL('SL028457.EVENT.LOCALQ') +
      REPLACE +
      PUT(ENABLED) +
      GET(ENABLED) +
      SHARE +
      DEFSOPT(EXCL) +
      MSGDLVSQ(FIFO) +
      DESCR('Local Queue for SL028457 events')
******************************************************

Monitoring MQ events from the mainframe


JCL for started task to run REXX code


//MVMQMP   PROC
//MONITOR  EXEC PGM=IRXJCL,
//                     PARM='MQMON INM1 SL028457.EVENT.LOCALQ'
//STEPLIB  DD DISP=SHR,DSN=SGMX.MASTER.LOAD    * REXX loadlib *
//         DD DISP=SHR,DSN=IN.MTMQSZDX.SCSQANLE
//         DD DISP=SHR,DSN=IN.MTMQSZDX.SCSQAUTH
//SYSEXEC  DD DISP=SHR,DSN=SG.DEVT.EXEC                * REXX execs */
//SYSTSPRT DD SYSOUT=*
'Parms' passed to the REXX code are set as follows:
o	MQMON
	REXX code (held in //SYSEXEC)
o	INM1
	MVS MQ server name
o	SL028457.EVENT.LOCALQ
	MQ local queue for events.



******************************************************



Calum Reid
Systems Programmer (UK)	c Xephon
